{# Copyright (C) 2021-2023 CERN. Copyright (C) 2021 Northwestern University. Copyright (C) 2026 University of Münster. Invenio App RDM is free software; you can redistribute it and/or modify it under the terms of the MIT License; see LICENSE file for more details. #} {%- set title = _("FAQ statistics") %} {%- extends config.BASE_TEMPLATE %} {%- block page_body %}

## Nutzungstatistiken

### Was wird erfasst?

Wir erfassen zwei Arten von Ereignissen:

- Aufrufe einer Datensatzseite
- Downloads von Dateien

Für beide Ereignistypen werden folgende Informationen gespeichert:

- Besucher*in: eine anonymisierte Besucher-ID

- Besucherart: ob die Anfrage von

  a) einem Menschen,

  b) automatisiert oder

  c) durch einen Crawler erfolgt ist.

- Land: Herkunftsland der Anfrage (basierend auf der IP-Adresse)

- Referrer: die Domain der verweisenden Website

### Was ist ein Aufruf („View“)?

Ein Aufruf ist der Besuch eines Datensatzes durch einen Nutzerin (manuell oder automatisiert).

Doppelklicks und Zugriffe durch Crawler werden nicht gezählt.

### Was ist ein eindeutiger Aufruf („Unique View“)?

Ein Aufruf ist der Besuch eines Datensatzes durch einen Nutzerin (manuell oder automatisiert).

Doppelklicks und Zugriffe durch Crawler werden nicht gezählt.

### Was ist ein Download?

Ein Download liegt vor, wenn eine Nutzerin manuell oder automatisiert eine Datei aus einem Datensatz herunterlädt.

Doppelklicks und Zugriffe durch Crawler werden auch hier nicht gezählt.

Besteht ein Datensatz aus mehreren Dateien, zählt jede heruntergeladene Datei als ein eigener Download.

### Was ist ein eindeutiger Download („Unique Download“)?

Ein eindeutiger Download umfasst einen oder mehrere Datei-Downloads aus demselben Datensatz durch dieselbe Person innerhalb eines Zeitfensters von einer Stunde.

Das heißt: Wer innerhalb einer Stunde mehrere Dateien desselben Datensatzes (oder dieselbe Datei mehrfach) herunterlädt, erzeugt nur einen eindeutigen Download.

### Was bedeutet „heruntergeladenes Datenvolumen“?

Das heruntergeladene Datenvolumen ist die Gesamtmenge aller heruntergeladenen Daten aus einem Datensatz, unabhängig davon ob der Download manuell oder automatisiert erfolgt ist.

Doppelklicks und Zugriffe durch Crawler werden auch hier nicht gezählt.

Wird ein Download vorzeitig abgebrochen, wird trotzdem die vollständige Dateigröße gezählt,

### Wie werden verschiedene Versionen eines Datensatzes berücksichtigt?

Standardmäßig zeigen wir zusammengefasste Statistiken über alle Versionen eines Datensatzes hinweg (Aufrufe, Downloads und Datenvolumen).

Auf der Datensatzseite können Sie den Statistikbereich erweitern, um die Nutzungszahlen für einzelne Versionen einzusehen.

### Wie wird mit Crawlern umgegangen?

Maschinelle Zugriffe durch Crawler, Bots etc. werden nicht in den Nutzungsstatistiken gezählt.

Die Erkennung erfolgt anhand einer standardisierten Liste, die von den Projekten COUNTER und Making Data Count bereitgestellt wird.

### Wie oft werden die Statistiken aktualisiert?

Einmal täglich.

### Wie finde ich die am häufigsten angesehenen Datensätze?

In jeder Suche in datastore können die Ergebnisse nach "am häufigsten angesehen" sortiert werden.

### Nach welchem Standard wird getrackt?

Die Erfassung erfolgt gemäß

- dem COUNTER Code of Practice und
- dem Code of Practice for Research Data Usage Metrics

Dadurch sind unsere Nutzungsstatistiken vergleichbar mit anderen COUNTER-konformen Repositorien.

### Was ist der Unterschied zwischen einer automatisierten und einer maschinellen Anfrage?

- Automatisierte Anfragen sind Zugriffe, die von Menschen ausgelöst werden, z.B. in Form eines Skripts welches Daten aus datastore herunterlädt und anschließend analysiert.
- Maschinelle Anfragen sind Zugriffe, die eigenständig durch Programme erfolgen, z. B. durch Suchmaschinen-Crawler oder andere Bots.

### Wie werden Nutzer*innen anonymisiert?

Für jeden Aufruf oder Download erfassen wir eine anonymisierte Besucher-ID.

- Diese Besucher-ID ändert sich alle 24 Stunden.

  Das bedeutet: Ruft dieselbe Person denselben Datensatz an zwei verschiedenen Tagen auf, entstehen zwei unterschiedliche anonymisierte IDs.

- Die anonymisierte Besucher-ID ist notwendig, um eindeutige Aufrufe und Downloads zählen zu können.

Für Sicherheitszwecke führen wir zudem ein Web‑Server‑Zugriffsprotokoll, das Ihre IP‑Adresse und den User‑Agent-String Ihres Browsers enthält. Dieses Web‑Server‑Zugriffsprotokoll wird nach höchstens einem Jahr automatisch gelöscht und ist zudem streng von der Erfassung der Nutzungsstatistiken getrennt.

Die anonymisierte Besucher-ID wird aus einem Nutzer-Merkmal abgeleitet, zum Beispiel:

- einer Nutzer-ID (z. B. wenn Sie eingeloggt sind),
- einer Sitzungs-ID,
- oder einer Kombination aus IP-Adresse und dem User Agent Ihres Browsers.

Dieses Merkmal wird:

1. mit einem zufälligen Textwert ("Salt") kombiniert
2. durch eine Einweg-Kryptofunktion verarbeitet (Hashing)

Der zufällige Textwert wird alle 24 Stunden neu erzeugt und anschließend verworfen. Dadurch ist die resultierende Besucher-ID nicht rückverfolgbar und vollständig zufällig.

### Kann ich der Erfassung von Nutzungsstatistiken widersprechen (Opt-out)?

Nein, ein Opt-out ist nicht möglich.

Die Erfassung erfolgt jedoch:

- vollständig anonymisiert
- serverseitig
- ohne personenbezogene Auswertung

### Gibt es Nutzungsstatistiken für Communities?

Aktuell noch nicht. Es ist jedoch geplant, künftig aggregierte Nutzungsstatistiken für Communities bereitzustellen.

### Werden meine Suchanfragen gespeichert?

Nein. Suchanfragen werden nicht getrackt.

### Findet eine manuelle oder automatische Profilbildung statt?

Nein. Es erfolgt keinerlei Profiling von Nutzer*innen.

{% endblock page_body %}